@@ -1,11 +1,11 @@
-/* glpies.h */
+/* glpies.h (implicit enumeration suite) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002 Andrew Makhorin <mao@mai2.rcnet.ru>,
---               Department for Applied Informatics, Moscow Aviation
---               Institute, Moscow, Russia. All rights reserved.
+-- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- Department for Applied Informatics, Moscow Aviation Institute,
+-- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is a part of GLPK (GNU Linear Programming Kit).
+-- This file is part of GLPK (GNU Linear Programming Kit).
 --
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
@@ -48,6 +48,7 @@
 #define ies_revive_node       glp_ies_revive_node
 #define ies_add_rows          glp_ies_add_rows
 #define ies_add_cols          glp_ies_add_cols
+#define ies_del_items         glp_ies_del_items
 #define ies_delete_node       glp_ies_delete_node
 #define ies_prune_branch      glp_ies_prune_branch
 #define ies_set_node_hook     glp_ies_set_node_hook
@@ -445,6 +446,9 @@ void ies_add_rows(IESTREE *tree, int nrs, IESITEM *row[]);
 void ies_add_cols(IESTREE *tree, int ncs, IESITEM *col[]);
 /* add master columns to the current node problem */
 
+void ies_del_items(IESTREE *tree);
+/* delete rows/columns from the current node problem */
+
 void ies_delete_node(IESTREE *tree, IESNODE *node);
 /* delete specified node problem */
 
