@@ -1,11 +1,11 @@
-/* glplib.h */
+/* glplib.h (miscellaneous low-level routines) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002 Andrew Makhorin <mao@mai2.rcnet.ru>,
---               Department for Applied Informatics, Moscow Aviation
---               Institute, Moscow, Russia. All rights reserved.
+-- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- Department for Applied Informatics, Moscow Aviation Institute,
+-- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is a part of GLPK (GNU Linear Programming Kit).
+-- This file is part of GLPK (GNU Linear Programming Kit).
 --
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 
 #define lib_set_ptr           glp_lib_set_ptr
 #define lib_get_ptr           glp_lib_get_ptr
+#define lib_get_time          glp_lib_get_time
 #define lib_init_env          glp_lib_init_env
 #define lib_env_ptr           glp_lib_env_ptr
 #define lib_free_env          glp_lib_free_env
@@ -41,11 +42,14 @@
 #define ufree                 glp_lib_ufree
 #define ufopen                glp_lib_ufopen
 #define ufclose               glp_lib_ufclose
-#define utime                 glp_lib_utime
 #define str2int               glp_lib_str2int
 #define str2dbl               glp_lib_str2dbl
 #define strspx                glp_lib_strspx
 #define strtrim               glp_lib_strtrim
+#define fp2rat                glp_lib_fp2rat
+#define lib_init_rand         glp_lib_init_rand
+#define lib_next_rand         glp_lib_next_rand
+#define lib_unif_rand         glp_lib_unif_rand
 
 typedef struct LIBENV LIBENV;
 typedef struct LIBMEM LIBMEM;
@@ -86,6 +90,12 @@ struct LIBENV
       void *file_slot[LIB_MAX_OPEN]; /* FILE *file_slot[]; */
       /* file_slot[k], 0 <= k <= LIB_MAX_OPEN-1, is a pointer to k-th
          i/o stream; if k-th slot is free, file_slot[k] is NULL */
+      /*--------------------------------------------------------------*/
+      /* pseudo-random number generator */
+      int rand_val[56];
+      /* pseudo-random values */
+      int *next_val;
+      /* the next pseudo-random value to be exported */
 };
 
 struct LIBMEM
@@ -111,6 +121,9 @@ void lib_set_ptr(void *ptr);
 void *lib_get_ptr(void);
 /* retrieve a pointer */
 
+double lib_get_time(void);
+/* determine the current universal time */
+
 int lib_init_env(void);
 /* initialize library environment */
 
@@ -163,7 +176,7 @@ void *ufopen(char *fname, char *mode);
 void ufclose(void *fp);
 /* close file */
 
-double utime(void);
+#define utime lib_get_time
 /* determine the current universal time */
 
 int str2int(char *str, int *val);
@@ -178,6 +191,18 @@ char *strspx(char *str);
 char *strtrim(char *str);
 /* remove trailing spaces from character string */
 
+int fp2rat(double x, double eps, double *p, double *q);
+/* convert floating-point number to rational number */
+
+void lib_init_rand(int seed);
+/* initialize pseudo-random number generator */
+
+int lib_next_rand(void);
+/* obtain pseudo-random integer in [0, 2^31-1] */
+
+int lib_unif_rand(int m);
+/* obtain pseudo-random integer in [0, m-1] */
+
 #endif
 
 /* eof */
